==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/cs.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zadaný operátor není platný",
    "The given regular expression is invalid" : "Zadaný regulární výraz je neplatný",
    "The given file size is invalid" : "Zadaná velikost souboru není platná",
    "The given tag id is invalid" : "Zadané id značky je neplatné",
    "The given IP range is invalid" : "Zadaný rozsah IP adres není platný",
    "The given IP range is not valid for IPv4" : "Zadaný rozsah IP je pro IPv4 neplatný",
    "The given IP range is not valid for IPv6" : "Zadaný IP rozsah není pro IPv6 platný",
    "The given time span is invalid" : "Zadaný časový rozsah je neplatný",
    "The given start time is invalid" : "Zadaný počáteční čas není platný",
    "The given end time is invalid" : "Zadaný koncový čas je neplatný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "Operation #%s does not exist" : "Operace č. %s neexistuje",
    "Operation %s does not exist" : "Operace %s neexistuje",
    "Operation %s is invalid" : "Operace %s není platná",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check #%s does not exist" : "Kontrola č. %s neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s je neplatná, nebo neexistuje",
    "Predefined URLs" : "Předdefinované URL",
    "Files WebDAV" : "Soubory WebDAV",
    "Sync clients" : "Synchronizační klienti",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "Thunderbird & Outlook addons" : "Doplňky pro Thunderbird a Outlook",
    "File name" : "Název souboru",
    "is" : "je",
    "is not" : "není",
    "matches" : "odpovídá",
    "does not match" : "neodpovídá",
    "File MIME type" : "MIME typ souboru",
    "File size (upload)" : "Velikost souboru (nahráno)",
    "less" : "menší",
    "less or equals" : "menší nebo rovno",
    "greater or equals" : "větší nebo rovno",
    "greater" : "větší",
    "Request remote address" : "Vzdálená adresa požadavku",
    "matches IPv4" : "odpovídá IPv4",
    "does not match IPv4" : "neodpovídá IPv4",
    "matches IPv6" : "odpovídá IPv6",
    "does not match IPv6" : "neodpovídá IPv6",
    "File system tag" : "Štítek souborového systému",
    "is tagged with" : "je označeno jako",
    "is not tagged with" : "není označen",
    "Request URL" : "URL požadavku",
    "Request time" : "Čas požadavku",
    "between" : "mezi",
    "not between" : "není mezi",
    "Request user agent" : "User agent požadavku",
    "User group membership" : "Členství ve skupině uživatelů",
    "is member of" : "je členem",
    "is not member of" : "není členem",
    "Short rule description" : "Krátký popis pravidla",
    "Add rule" : "Přidat pravidlo",
    "Reset" : "Obnovit",
    "Save" : "Uložit",
    "Saving…" : "Ukládání…",
    "Group list is empty" : "Seznam skupin je prázdný",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupin",
    "Saved" : "Uloženo",
    "Saving failed:" : "Ukládání se nezdařilo:",
    "Add rule group" : "Přidat skupinu pravidel",
    "Example: {placeholder}" : "Příklad: {placeholder}",
    "Select tag…" : "Vybrat štítek…",
    "Start" : "Začátek",
    "End" : "Konec",
    "Select timezone…" : "Vybrat časové pásmo…",
    "Workflow" : "Postup práce",
    "Files workflow engine" : "Engine práce se soubory",
    "Open documentation" : "Otevřít dokumentaci",
    "Loading…" : "Načítání…",
    "Tag management" : "Správa štítků"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/cs.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zadaný operátor není platný",
    "The given regular expression is invalid" : "Zadaný regulární výraz je neplatný",
    "The given file size is invalid" : "Zadaná velikost souboru není platná",
    "The given tag id is invalid" : "Zadané id značky je neplatné",
    "The given IP range is invalid" : "Zadaný rozsah IP adres není platný",
    "The given IP range is not valid for IPv4" : "Zadaný rozsah IP je pro IPv4 neplatný",
    "The given IP range is not valid for IPv6" : "Zadaný IP rozsah není pro IPv6 platný",
    "The given time span is invalid" : "Zadaný časový rozsah je neplatný",
    "The given start time is invalid" : "Zadaný počáteční čas není platný",
    "The given end time is invalid" : "Zadaný koncový čas je neplatný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "File" : "Soubor",
    "File created" : "Soubor vytvořen",
    "File updated" : "Soubor aktualizován",
    "File renamed" : "Soubor přejmenován",
    "File deleted" : "Soubor smazán",
    "File accessed" : "K souboru přistoupeno",
    "File copied" : "Soubor zkopírován",
    "Tag assigned" : "Štítek přiřazen",
    "Operation #%s does not exist" : "Operace č. %s neexistuje",
    "Entity %s does not exist" : "Entita %s neexistuje",
    "Entity %s is invalid" : "Entita %s není platná",
    "No events are chosen." : "Nejsou zvolené žádné události",
    "Operation %s does not exist" : "Operace %s neexistuje",
    "Operation %s is invalid" : "Operace %s není platná",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check #%s does not exist" : "Kontrola č. %s neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s je neplatná, nebo neexistuje",
    "Select a filter" : "Vybrat filtr",
    "Select a comparator" : "Vyberte porovnání",
    "Select a file type" : "Vybrat typ souboru",
    "Images" : "Obrázky",
    "Office documents" : "Kancelářské dokumenty",
    "PDF documents" : "PDF dokumenty",
    "No results" : "Žádné výsledky",
    "%s (invisible)" : "%s (neviditelné)",
    "%s (restricted)" : "%s (omezeno)",
    "Predefined URLs" : "Předdefinované URL",
    "Files WebDAV" : "Soubory WebDAV",
    "Others" : "Ostatní",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "Thunderbird & Outlook addons" : "Doplňky pro Thunderbird a Outlook",
    "When" : "Kdy",
    "and" : "a",
    "The configuration is invalid" : "Nastavení není platné",
    "Show less" : "Zobrazit méně",
    "Show more" : "Zobrazit více",
    "File name" : "Název souboru",
    "is" : "je",
    "is not" : "není",
    "matches" : "odpovídá",
    "does not match" : "neodpovídá",
    "File MIME type" : "MIME typ souboru",
    "File size (upload)" : "Velikost souboru (nahráno)",
    "less" : "menší",
    "less or equals" : "menší nebo rovno",
    "greater or equals" : "větší nebo rovno",
    "greater" : "větší",
    "Request remote address" : "Vzdálená adresa požadavku",
    "matches IPv4" : "odpovídá IPv4",
    "does not match IPv4" : "neodpovídá IPv4",
    "matches IPv6" : "odpovídá IPv6",
    "does not match IPv6" : "neodpovídá IPv6",
    "File system tag" : "Štítek souborového systému",
    "is tagged with" : "je označeno jako",
    "is not tagged with" : "není označen",
    "Request URL" : "URL požadavku",
    "Request time" : "Čas požadavku",
    "between" : "mezi",
    "not between" : "není mezi",
    "Request user agent" : "User agent požadavku",
    "User group membership" : "Členství ve skupině uživatelů",
    "is member of" : "je členem",
    "is not member of" : "není členem",
    "Short rule description" : "Krátký popis pravidla",
    "Add rule" : "Přidat pravidlo",
    "Reset" : "Obnovit",
    "Save" : "Uložit",
    "Saving…" : "Ukládání…",
    "Group list is empty" : "Seznam skupin je prázdný",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupin",
    "Saved" : "Uloženo",
    "Saving failed:" : "Ukládání se nezdařilo:",
    "Add rule group" : "Přidat skupinu pravidel",
    "Example: {placeholder}" : "Příklad: {placeholder}",
    "Select tag…" : "Vybrat štítek…",
    "Start" : "Začátek",
    "End" : "Konec",
    "Select timezone…" : "Vybrat časové pásmo…",
    "Sync clients" : "Synchronizační klienti",
    "Workflow" : "Postup práce",
    "Files workflow engine" : "Engine práce se soubory",
    "Open documentation" : "Otevřít dokumentaci",
    "Loading…" : "Načítání…",
    "Tag management" : "Správa štítků"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
